@@ -390,11 +390,6 @@ bool DrKonqi::isEphemeralCrash()
 #endif
 }
 
-void DrKonqi::cleanupBeforeQuit()
-{
-    instance()->m_backend->cleanup();
-}
-
 bool DrKonqi::minimalMode()
 {
     return qEnvironmentVariableIntValue("DRKONQI_MINIMAL_MODE") > 0;
